# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include budgets_service.R
NULL

#' Creates a budget and, if included, notifications and subscribers
#'
#' @description
#' Creates a budget and, if included, notifications and subscribers.
#' 
#' Only one of `BudgetLimit` or `PlannedBudgetLimits` can be present in the
#' syntax at one time. Use the syntax that matches your case. The Request
#' Syntax section shows the `BudgetLimit` syntax. For
#' `PlannedBudgetLimits`, see the
#' [Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_CreateBudget.html#API_CreateBudget_Examples)
#' section.
#'
#' @usage
#' budgets_create_budget(AccountId, Budget, NotificationsWithSubscribers)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget.
#' @param Budget &#91;required&#93; The budget object that you want to create.
#' @param NotificationsWithSubscribers A notification that you want to associate with a budget. A budget can
#' have up to five notifications, and each notification can have one SNS
#' subscriber and up to 10 email subscribers. If you include notifications
#' and subscribers in your `CreateBudget` call, AWS creates the
#' notifications and subscribers for you.
#'
#' @section Request syntax:
#' ```
#' svc$create_budget(
#'   AccountId = "string",
#'   Budget = list(
#'     BudgetName = "string",
#'     BudgetLimit = list(
#'       Amount = "string",
#'       Unit = "string"
#'     ),
#'     PlannedBudgetLimits = list(
#'       list(
#'         Amount = "string",
#'         Unit = "string"
#'       )
#'     ),
#'     CostFilters = list(
#'       list(
#'         "string"
#'       )
#'     ),
#'     CostTypes = list(
#'       IncludeTax = TRUE|FALSE,
#'       IncludeSubscription = TRUE|FALSE,
#'       UseBlended = TRUE|FALSE,
#'       IncludeRefund = TRUE|FALSE,
#'       IncludeCredit = TRUE|FALSE,
#'       IncludeUpfront = TRUE|FALSE,
#'       IncludeRecurring = TRUE|FALSE,
#'       IncludeOtherSubscription = TRUE|FALSE,
#'       IncludeSupport = TRUE|FALSE,
#'       IncludeDiscount = TRUE|FALSE,
#'       UseAmortized = TRUE|FALSE
#'     ),
#'     TimeUnit = "DAILY"|"MONTHLY"|"QUARTERLY"|"ANNUALLY",
#'     TimePeriod = list(
#'       Start = as.POSIXct(
#'         "2015-01-01"
#'       ),
#'       End = as.POSIXct(
#'         "2015-01-01"
#'       )
#'     ),
#'     CalculatedSpend = list(
#'       ActualSpend = list(
#'         Amount = "string",
#'         Unit = "string"
#'       ),
#'       ForecastedSpend = list(
#'         Amount = "string",
#'         Unit = "string"
#'       )
#'     ),
#'     BudgetType = "USAGE"|"COST"|"RI_UTILIZATION"|"RI_COVERAGE"|"SAVINGS_PLANS_UTILIZATION"|"SAVINGS_PLANS_COVERAGE",
#'     LastUpdatedTime = as.POSIXct(
#'       "2015-01-01"
#'     )
#'   ),
#'   NotificationsWithSubscribers = list(
#'     list(
#'       Notification = list(
#'         NotificationType = "ACTUAL"|"FORECASTED",
#'         ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'         Threshold = 123.0,
#'         ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'         NotificationState = "OK"|"ALARM"
#'       ),
#'       Subscribers = list(
#'         list(
#'           SubscriptionType = "SNS"|"EMAIL",
#'           Address = "string"
#'         )
#'       )
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_create_budget
budgets_create_budget <- function(AccountId, Budget, NotificationsWithSubscribers = NULL) {
  op <- new_operation(
    name = "CreateBudget",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$create_budget_input(AccountId = AccountId, Budget = Budget, NotificationsWithSubscribers = NotificationsWithSubscribers)
  output <- .budgets$create_budget_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$create_budget <- budgets_create_budget

#' Creates a budget action
#'
#' @description
#' Creates a budget action.
#'
#' @usage
#' budgets_create_budget_action(AccountId, BudgetName, NotificationType,
#'   ActionType, ActionThreshold, Definition, ExecutionRoleArn,
#'   ApprovalModel, Subscribers)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param NotificationType &#91;required&#93; 
#' @param ActionType &#91;required&#93; The type of action. This defines the type of tasks that can be carried
#' out by this action. This field also determines the format for
#' definition.
#' @param ActionThreshold &#91;required&#93; 
#' @param Definition &#91;required&#93; 
#' @param ExecutionRoleArn &#91;required&#93; The role passed for action execution and reversion. Roles and actions
#' must be in the same account.
#' @param ApprovalModel &#91;required&#93; This specifies if the action needs manual or automatic approval.
#' @param Subscribers &#91;required&#93; 
#'
#' @section Request syntax:
#' ```
#' svc$create_budget_action(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   NotificationType = "ACTUAL"|"FORECASTED",
#'   ActionType = "APPLY_IAM_POLICY"|"APPLY_SCP_POLICY"|"RUN_SSM_DOCUMENTS",
#'   ActionThreshold = list(
#'     ActionThresholdValue = 123.0,
#'     ActionThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE"
#'   ),
#'   Definition = list(
#'     IamActionDefinition = list(
#'       PolicyArn = "string",
#'       Roles = list(
#'         "string"
#'       ),
#'       Groups = list(
#'         "string"
#'       ),
#'       Users = list(
#'         "string"
#'       )
#'     ),
#'     ScpActionDefinition = list(
#'       PolicyId = "string",
#'       TargetIds = list(
#'         "string"
#'       )
#'     ),
#'     SsmActionDefinition = list(
#'       ActionSubType = "STOP_EC2_INSTANCES"|"STOP_RDS_INSTANCES",
#'       Region = "string",
#'       InstanceIds = list(
#'         "string"
#'       )
#'     )
#'   ),
#'   ExecutionRoleArn = "string",
#'   ApprovalModel = "AUTOMATIC"|"MANUAL",
#'   Subscribers = list(
#'     list(
#'       SubscriptionType = "SNS"|"EMAIL",
#'       Address = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_create_budget_action
budgets_create_budget_action <- function(AccountId, BudgetName, NotificationType, ActionType, ActionThreshold, Definition, ExecutionRoleArn, ApprovalModel, Subscribers) {
  op <- new_operation(
    name = "CreateBudgetAction",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$create_budget_action_input(AccountId = AccountId, BudgetName = BudgetName, NotificationType = NotificationType, ActionType = ActionType, ActionThreshold = ActionThreshold, Definition = Definition, ExecutionRoleArn = ExecutionRoleArn, ApprovalModel = ApprovalModel, Subscribers = Subscribers)
  output <- .budgets$create_budget_action_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$create_budget_action <- budgets_create_budget_action

#' Creates a notification
#'
#' @description
#' Creates a notification. You must create the budget before you create the
#' associated notification.
#'
#' @usage
#' budgets_create_notification(AccountId, BudgetName, Notification,
#'   Subscribers)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget that you want to
#' create a notification for.
#' @param BudgetName &#91;required&#93; The name of the budget that you want AWS to notify you about. Budget
#' names must be unique within an account.
#' @param Notification &#91;required&#93; The notification that you want to create.
#' @param Subscribers &#91;required&#93; A list of subscribers that you want to associate with the notification.
#' Each notification can have one SNS subscriber and up to 10 email
#' subscribers.
#'
#' @section Request syntax:
#' ```
#' svc$create_notification(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   Notification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   ),
#'   Subscribers = list(
#'     list(
#'       SubscriptionType = "SNS"|"EMAIL",
#'       Address = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_create_notification
budgets_create_notification <- function(AccountId, BudgetName, Notification, Subscribers) {
  op <- new_operation(
    name = "CreateNotification",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$create_notification_input(AccountId = AccountId, BudgetName = BudgetName, Notification = Notification, Subscribers = Subscribers)
  output <- .budgets$create_notification_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$create_notification <- budgets_create_notification

#' Creates a subscriber
#'
#' @description
#' Creates a subscriber. You must create the associated budget and
#' notification before you create the subscriber.
#'
#' @usage
#' budgets_create_subscriber(AccountId, BudgetName, Notification,
#'   Subscriber)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget that you want to
#' create a subscriber for.
#' @param BudgetName &#91;required&#93; The name of the budget that you want to subscribe to. Budget names must
#' be unique within an account.
#' @param Notification &#91;required&#93; The notification that you want to create a subscriber for.
#' @param Subscriber &#91;required&#93; The subscriber that you want to associate with a budget notification.
#'
#' @section Request syntax:
#' ```
#' svc$create_subscriber(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   Notification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   ),
#'   Subscriber = list(
#'     SubscriptionType = "SNS"|"EMAIL",
#'     Address = "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_create_subscriber
budgets_create_subscriber <- function(AccountId, BudgetName, Notification, Subscriber) {
  op <- new_operation(
    name = "CreateSubscriber",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$create_subscriber_input(AccountId = AccountId, BudgetName = BudgetName, Notification = Notification, Subscriber = Subscriber)
  output <- .budgets$create_subscriber_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$create_subscriber <- budgets_create_subscriber

#' Deletes a budget
#'
#' @description
#' Deletes a budget. You can delete your budget at any time.
#' 
#' Deleting a budget also deletes the notifications and subscribers that
#' are associated with that budget.
#'
#' @usage
#' budgets_delete_budget(AccountId, BudgetName)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget that you want to
#' delete.
#' @param BudgetName &#91;required&#93; The name of the budget that you want to delete.
#'
#' @section Request syntax:
#' ```
#' svc$delete_budget(
#'   AccountId = "string",
#'   BudgetName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_delete_budget
budgets_delete_budget <- function(AccountId, BudgetName) {
  op <- new_operation(
    name = "DeleteBudget",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$delete_budget_input(AccountId = AccountId, BudgetName = BudgetName)
  output <- .budgets$delete_budget_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$delete_budget <- budgets_delete_budget

#' Deletes a budget action
#'
#' @description
#' Deletes a budget action.
#'
#' @usage
#' budgets_delete_budget_action(AccountId, BudgetName, ActionId)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param ActionId &#91;required&#93; A system-generated universally unique identifier (UUID) for the action.
#'
#' @section Request syntax:
#' ```
#' svc$delete_budget_action(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   ActionId = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_delete_budget_action
budgets_delete_budget_action <- function(AccountId, BudgetName, ActionId) {
  op <- new_operation(
    name = "DeleteBudgetAction",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$delete_budget_action_input(AccountId = AccountId, BudgetName = BudgetName, ActionId = ActionId)
  output <- .budgets$delete_budget_action_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$delete_budget_action <- budgets_delete_budget_action

#' Deletes a notification
#'
#' @description
#' Deletes a notification.
#' 
#' Deleting a notification also deletes the subscribers that are associated
#' with the notification.
#'
#' @usage
#' budgets_delete_notification(AccountId, BudgetName, Notification)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget whose notification
#' you want to delete.
#' @param BudgetName &#91;required&#93; The name of the budget whose notification you want to delete.
#' @param Notification &#91;required&#93; The notification that you want to delete.
#'
#' @section Request syntax:
#' ```
#' svc$delete_notification(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   Notification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_delete_notification
budgets_delete_notification <- function(AccountId, BudgetName, Notification) {
  op <- new_operation(
    name = "DeleteNotification",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$delete_notification_input(AccountId = AccountId, BudgetName = BudgetName, Notification = Notification)
  output <- .budgets$delete_notification_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$delete_notification <- budgets_delete_notification

#' Deletes a subscriber
#'
#' @description
#' Deletes a subscriber.
#' 
#' Deleting the last subscriber to a notification also deletes the
#' notification.
#'
#' @usage
#' budgets_delete_subscriber(AccountId, BudgetName, Notification,
#'   Subscriber)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget whose subscriber you
#' want to delete.
#' @param BudgetName &#91;required&#93; The name of the budget whose subscriber you want to delete.
#' @param Notification &#91;required&#93; The notification whose subscriber you want to delete.
#' @param Subscriber &#91;required&#93; The subscriber that you want to delete.
#'
#' @section Request syntax:
#' ```
#' svc$delete_subscriber(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   Notification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   ),
#'   Subscriber = list(
#'     SubscriptionType = "SNS"|"EMAIL",
#'     Address = "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_delete_subscriber
budgets_delete_subscriber <- function(AccountId, BudgetName, Notification, Subscriber) {
  op <- new_operation(
    name = "DeleteSubscriber",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$delete_subscriber_input(AccountId = AccountId, BudgetName = BudgetName, Notification = Notification, Subscriber = Subscriber)
  output <- .budgets$delete_subscriber_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$delete_subscriber <- budgets_delete_subscriber

#' Describes a budget
#'
#' @description
#' Describes a budget.
#' 
#' The Request Syntax section shows the `BudgetLimit` syntax. For
#' `PlannedBudgetLimits`, see the
#' [Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudget.html#API_DescribeBudget_Examples)
#' section.
#'
#' @usage
#' budgets_describe_budget(AccountId, BudgetName)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget that you want a
#' description of.
#' @param BudgetName &#91;required&#93; The name of the budget that you want a description of.
#'
#' @section Request syntax:
#' ```
#' svc$describe_budget(
#'   AccountId = "string",
#'   BudgetName = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budget
budgets_describe_budget <- function(AccountId, BudgetName) {
  op <- new_operation(
    name = "DescribeBudget",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budget_input(AccountId = AccountId, BudgetName = BudgetName)
  output <- .budgets$describe_budget_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budget <- budgets_describe_budget

#' Describes a budget action detail
#'
#' @description
#' Describes a budget action detail.
#'
#' @usage
#' budgets_describe_budget_action(AccountId, BudgetName, ActionId)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param ActionId &#91;required&#93; A system-generated universally unique identifier (UUID) for the action.
#'
#' @section Request syntax:
#' ```
#' svc$describe_budget_action(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   ActionId = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budget_action
budgets_describe_budget_action <- function(AccountId, BudgetName, ActionId) {
  op <- new_operation(
    name = "DescribeBudgetAction",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budget_action_input(AccountId = AccountId, BudgetName = BudgetName, ActionId = ActionId)
  output <- .budgets$describe_budget_action_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budget_action <- budgets_describe_budget_action

#' Describes a budget action history detail
#'
#' @description
#' Describes a budget action history detail.
#'
#' @usage
#' budgets_describe_budget_action_histories(AccountId, BudgetName,
#'   ActionId, TimePeriod, MaxResults, NextToken)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param ActionId &#91;required&#93; A system-generated universally unique identifier (UUID) for the action.
#' @param TimePeriod 
#' @param MaxResults 
#' @param NextToken 
#'
#' @section Request syntax:
#' ```
#' svc$describe_budget_action_histories(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   ActionId = "string",
#'   TimePeriod = list(
#'     Start = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     End = as.POSIXct(
#'       "2015-01-01"
#'     )
#'   ),
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budget_action_histories
budgets_describe_budget_action_histories <- function(AccountId, BudgetName, ActionId, TimePeriod = NULL, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeBudgetActionHistories",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budget_action_histories_input(AccountId = AccountId, BudgetName = BudgetName, ActionId = ActionId, TimePeriod = TimePeriod, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_budget_action_histories_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budget_action_histories <- budgets_describe_budget_action_histories

#' Describes all of the budget actions for an account
#'
#' @description
#' Describes all of the budget actions for an account.
#'
#' @usage
#' budgets_describe_budget_actions_for_account(AccountId, MaxResults,
#'   NextToken)
#'
#' @param AccountId &#91;required&#93; 
#' @param MaxResults 
#' @param NextToken 
#'
#' @section Request syntax:
#' ```
#' svc$describe_budget_actions_for_account(
#'   AccountId = "string",
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budget_actions_for_account
budgets_describe_budget_actions_for_account <- function(AccountId, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeBudgetActionsForAccount",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budget_actions_for_account_input(AccountId = AccountId, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_budget_actions_for_account_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budget_actions_for_account <- budgets_describe_budget_actions_for_account

#' Describes all of the budget actions for a budget
#'
#' @description
#' Describes all of the budget actions for a budget.
#'
#' @usage
#' budgets_describe_budget_actions_for_budget(AccountId, BudgetName,
#'   MaxResults, NextToken)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param MaxResults 
#' @param NextToken 
#'
#' @section Request syntax:
#' ```
#' svc$describe_budget_actions_for_budget(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budget_actions_for_budget
budgets_describe_budget_actions_for_budget <- function(AccountId, BudgetName, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeBudgetActionsForBudget",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budget_actions_for_budget_input(AccountId = AccountId, BudgetName = BudgetName, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_budget_actions_for_budget_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budget_actions_for_budget <- budgets_describe_budget_actions_for_budget

#' Describes the history for DAILY, MONTHLY, and QUARTERLY budgets
#'
#' @description
#' Describes the history for `DAILY`, `MONTHLY`, and `QUARTERLY` budgets.
#' Budget history isn't available for `ANNUAL` budgets.
#'
#' @usage
#' budgets_describe_budget_performance_history(AccountId, BudgetName,
#'   TimePeriod, MaxResults, NextToken)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param TimePeriod Retrieves how often the budget went into an `ALARM` state for the
#' specified time period.
#' @param MaxResults 
#' @param NextToken 
#'
#' @section Request syntax:
#' ```
#' svc$describe_budget_performance_history(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   TimePeriod = list(
#'     Start = as.POSIXct(
#'       "2015-01-01"
#'     ),
#'     End = as.POSIXct(
#'       "2015-01-01"
#'     )
#'   ),
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budget_performance_history
budgets_describe_budget_performance_history <- function(AccountId, BudgetName, TimePeriod = NULL, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeBudgetPerformanceHistory",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budget_performance_history_input(AccountId = AccountId, BudgetName = BudgetName, TimePeriod = TimePeriod, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_budget_performance_history_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budget_performance_history <- budgets_describe_budget_performance_history

#' Lists the budgets that are associated with an account
#'
#' @description
#' Lists the budgets that are associated with an account.
#' 
#' The Request Syntax section shows the `BudgetLimit` syntax. For
#' `PlannedBudgetLimits`, see the
#' [Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_DescribeBudgets.html#API_DescribeBudgets_Examples)
#' section.
#'
#' @usage
#' budgets_describe_budgets(AccountId, MaxResults, NextToken)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budgets that you want
#' descriptions of.
#' @param MaxResults An optional integer that represents how many entries a paginated
#' response contains. The maximum is 100.
#' @param NextToken The pagination token that you include in your request to indicate the
#' next set of results that you want to retrieve.
#'
#' @section Request syntax:
#' ```
#' svc$describe_budgets(
#'   AccountId = "string",
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_budgets
budgets_describe_budgets <- function(AccountId, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeBudgets",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_budgets_input(AccountId = AccountId, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_budgets_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_budgets <- budgets_describe_budgets

#' Lists the notifications that are associated with a budget
#'
#' @description
#' Lists the notifications that are associated with a budget.
#'
#' @usage
#' budgets_describe_notifications_for_budget(AccountId, BudgetName,
#'   MaxResults, NextToken)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget whose notifications
#' you want descriptions of.
#' @param BudgetName &#91;required&#93; The name of the budget whose notifications you want descriptions of.
#' @param MaxResults An optional integer that represents how many entries a paginated
#' response contains. The maximum is 100.
#' @param NextToken The pagination token that you include in your request to indicate the
#' next set of results that you want to retrieve.
#'
#' @section Request syntax:
#' ```
#' svc$describe_notifications_for_budget(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_notifications_for_budget
budgets_describe_notifications_for_budget <- function(AccountId, BudgetName, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeNotificationsForBudget",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_notifications_for_budget_input(AccountId = AccountId, BudgetName = BudgetName, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_notifications_for_budget_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_notifications_for_budget <- budgets_describe_notifications_for_budget

#' Lists the subscribers that are associated with a notification
#'
#' @description
#' Lists the subscribers that are associated with a notification.
#'
#' @usage
#' budgets_describe_subscribers_for_notification(AccountId, BudgetName,
#'   Notification, MaxResults, NextToken)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget whose subscribers you
#' want descriptions of.
#' @param BudgetName &#91;required&#93; The name of the budget whose subscribers you want descriptions of.
#' @param Notification &#91;required&#93; The notification whose subscribers you want to list.
#' @param MaxResults An optional integer that represents how many entries a paginated
#' response contains. The maximum is 100.
#' @param NextToken The pagination token that you include in your request to indicate the
#' next set of results that you want to retrieve.
#'
#' @section Request syntax:
#' ```
#' svc$describe_subscribers_for_notification(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   Notification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   ),
#'   MaxResults = 123,
#'   NextToken = "string"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_describe_subscribers_for_notification
budgets_describe_subscribers_for_notification <- function(AccountId, BudgetName, Notification, MaxResults = NULL, NextToken = NULL) {
  op <- new_operation(
    name = "DescribeSubscribersForNotification",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$describe_subscribers_for_notification_input(AccountId = AccountId, BudgetName = BudgetName, Notification = Notification, MaxResults = MaxResults, NextToken = NextToken)
  output <- .budgets$describe_subscribers_for_notification_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$describe_subscribers_for_notification <- budgets_describe_subscribers_for_notification

#' Executes a budget action
#'
#' @description
#' Executes a budget action.
#'
#' @usage
#' budgets_execute_budget_action(AccountId, BudgetName, ActionId,
#'   ExecutionType)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param ActionId &#91;required&#93; A system-generated universally unique identifier (UUID) for the action.
#' @param ExecutionType &#91;required&#93; The type of execution.
#'
#' @section Request syntax:
#' ```
#' svc$execute_budget_action(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   ActionId = "string",
#'   ExecutionType = "APPROVE_BUDGET_ACTION"|"RETRY_BUDGET_ACTION"|"REVERSE_BUDGET_ACTION"|"RESET_BUDGET_ACTION"
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_execute_budget_action
budgets_execute_budget_action <- function(AccountId, BudgetName, ActionId, ExecutionType) {
  op <- new_operation(
    name = "ExecuteBudgetAction",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$execute_budget_action_input(AccountId = AccountId, BudgetName = BudgetName, ActionId = ActionId, ExecutionType = ExecutionType)
  output <- .budgets$execute_budget_action_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$execute_budget_action <- budgets_execute_budget_action

#' Updates a budget
#'
#' @description
#' Updates a budget. You can change every part of a budget except for the
#' `budgetName` and the `calculatedSpend`. When you modify a budget, the
#' `calculatedSpend` drops to zero until AWS has new usage data to use for
#' forecasting.
#' 
#' Only one of `BudgetLimit` or `PlannedBudgetLimits` can be present in the
#' syntax at one time. Use the syntax that matches your case. The Request
#' Syntax section shows the `BudgetLimit` syntax. For
#' `PlannedBudgetLimits`, see the
#' [Examples](https://docs.aws.amazon.com/aws-cost-management/latest/APIReference/API_budgets_UpdateBudget.html#API_UpdateBudget_Examples)
#' section.
#'
#' @usage
#' budgets_update_budget(AccountId, NewBudget)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget that you want to
#' update.
#' @param NewBudget &#91;required&#93; The budget that you want to update your budget to.
#'
#' @section Request syntax:
#' ```
#' svc$update_budget(
#'   AccountId = "string",
#'   NewBudget = list(
#'     BudgetName = "string",
#'     BudgetLimit = list(
#'       Amount = "string",
#'       Unit = "string"
#'     ),
#'     PlannedBudgetLimits = list(
#'       list(
#'         Amount = "string",
#'         Unit = "string"
#'       )
#'     ),
#'     CostFilters = list(
#'       list(
#'         "string"
#'       )
#'     ),
#'     CostTypes = list(
#'       IncludeTax = TRUE|FALSE,
#'       IncludeSubscription = TRUE|FALSE,
#'       UseBlended = TRUE|FALSE,
#'       IncludeRefund = TRUE|FALSE,
#'       IncludeCredit = TRUE|FALSE,
#'       IncludeUpfront = TRUE|FALSE,
#'       IncludeRecurring = TRUE|FALSE,
#'       IncludeOtherSubscription = TRUE|FALSE,
#'       IncludeSupport = TRUE|FALSE,
#'       IncludeDiscount = TRUE|FALSE,
#'       UseAmortized = TRUE|FALSE
#'     ),
#'     TimeUnit = "DAILY"|"MONTHLY"|"QUARTERLY"|"ANNUALLY",
#'     TimePeriod = list(
#'       Start = as.POSIXct(
#'         "2015-01-01"
#'       ),
#'       End = as.POSIXct(
#'         "2015-01-01"
#'       )
#'     ),
#'     CalculatedSpend = list(
#'       ActualSpend = list(
#'         Amount = "string",
#'         Unit = "string"
#'       ),
#'       ForecastedSpend = list(
#'         Amount = "string",
#'         Unit = "string"
#'       )
#'     ),
#'     BudgetType = "USAGE"|"COST"|"RI_UTILIZATION"|"RI_COVERAGE"|"SAVINGS_PLANS_UTILIZATION"|"SAVINGS_PLANS_COVERAGE",
#'     LastUpdatedTime = as.POSIXct(
#'       "2015-01-01"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_update_budget
budgets_update_budget <- function(AccountId, NewBudget) {
  op <- new_operation(
    name = "UpdateBudget",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$update_budget_input(AccountId = AccountId, NewBudget = NewBudget)
  output <- .budgets$update_budget_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$update_budget <- budgets_update_budget

#' Updates a budget action
#'
#' @description
#' Updates a budget action.
#'
#' @usage
#' budgets_update_budget_action(AccountId, BudgetName, ActionId,
#'   NotificationType, ActionThreshold, Definition, ExecutionRoleArn,
#'   ApprovalModel, Subscribers)
#'
#' @param AccountId &#91;required&#93; 
#' @param BudgetName &#91;required&#93; 
#' @param ActionId &#91;required&#93; A system-generated universally unique identifier (UUID) for the action.
#' @param NotificationType 
#' @param ActionThreshold 
#' @param Definition 
#' @param ExecutionRoleArn The role passed for action execution and reversion. Roles and actions
#' must be in the same account.
#' @param ApprovalModel This specifies if the action needs manual or automatic approval.
#' @param Subscribers 
#'
#' @section Request syntax:
#' ```
#' svc$update_budget_action(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   ActionId = "string",
#'   NotificationType = "ACTUAL"|"FORECASTED",
#'   ActionThreshold = list(
#'     ActionThresholdValue = 123.0,
#'     ActionThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE"
#'   ),
#'   Definition = list(
#'     IamActionDefinition = list(
#'       PolicyArn = "string",
#'       Roles = list(
#'         "string"
#'       ),
#'       Groups = list(
#'         "string"
#'       ),
#'       Users = list(
#'         "string"
#'       )
#'     ),
#'     ScpActionDefinition = list(
#'       PolicyId = "string",
#'       TargetIds = list(
#'         "string"
#'       )
#'     ),
#'     SsmActionDefinition = list(
#'       ActionSubType = "STOP_EC2_INSTANCES"|"STOP_RDS_INSTANCES",
#'       Region = "string",
#'       InstanceIds = list(
#'         "string"
#'       )
#'     )
#'   ),
#'   ExecutionRoleArn = "string",
#'   ApprovalModel = "AUTOMATIC"|"MANUAL",
#'   Subscribers = list(
#'     list(
#'       SubscriptionType = "SNS"|"EMAIL",
#'       Address = "string"
#'     )
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_update_budget_action
budgets_update_budget_action <- function(AccountId, BudgetName, ActionId, NotificationType = NULL, ActionThreshold = NULL, Definition = NULL, ExecutionRoleArn = NULL, ApprovalModel = NULL, Subscribers = NULL) {
  op <- new_operation(
    name = "UpdateBudgetAction",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$update_budget_action_input(AccountId = AccountId, BudgetName = BudgetName, ActionId = ActionId, NotificationType = NotificationType, ActionThreshold = ActionThreshold, Definition = Definition, ExecutionRoleArn = ExecutionRoleArn, ApprovalModel = ApprovalModel, Subscribers = Subscribers)
  output <- .budgets$update_budget_action_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$update_budget_action <- budgets_update_budget_action

#' Updates a notification
#'
#' @description
#' Updates a notification.
#'
#' @usage
#' budgets_update_notification(AccountId, BudgetName, OldNotification,
#'   NewNotification)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget whose notification
#' you want to update.
#' @param BudgetName &#91;required&#93; The name of the budget whose notification you want to update.
#' @param OldNotification &#91;required&#93; The previous notification that is associated with a budget.
#' @param NewNotification &#91;required&#93; The updated notification to be associated with a budget.
#'
#' @section Request syntax:
#' ```
#' svc$update_notification(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   OldNotification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   ),
#'   NewNotification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_update_notification
budgets_update_notification <- function(AccountId, BudgetName, OldNotification, NewNotification) {
  op <- new_operation(
    name = "UpdateNotification",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$update_notification_input(AccountId = AccountId, BudgetName = BudgetName, OldNotification = OldNotification, NewNotification = NewNotification)
  output <- .budgets$update_notification_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$update_notification <- budgets_update_notification

#' Updates a subscriber
#'
#' @description
#' Updates a subscriber.
#'
#' @usage
#' budgets_update_subscriber(AccountId, BudgetName, Notification,
#'   OldSubscriber, NewSubscriber)
#'
#' @param AccountId &#91;required&#93; The `accountId` that is associated with the budget whose subscriber you
#' want to update.
#' @param BudgetName &#91;required&#93; The name of the budget whose subscriber you want to update.
#' @param Notification &#91;required&#93; The notification whose subscriber you want to update.
#' @param OldSubscriber &#91;required&#93; The previous subscriber that is associated with a budget notification.
#' @param NewSubscriber &#91;required&#93; The updated subscriber that is associated with a budget notification.
#'
#' @section Request syntax:
#' ```
#' svc$update_subscriber(
#'   AccountId = "string",
#'   BudgetName = "string",
#'   Notification = list(
#'     NotificationType = "ACTUAL"|"FORECASTED",
#'     ComparisonOperator = "GREATER_THAN"|"LESS_THAN"|"EQUAL_TO",
#'     Threshold = 123.0,
#'     ThresholdType = "PERCENTAGE"|"ABSOLUTE_VALUE",
#'     NotificationState = "OK"|"ALARM"
#'   ),
#'   OldSubscriber = list(
#'     SubscriptionType = "SNS"|"EMAIL",
#'     Address = "string"
#'   ),
#'   NewSubscriber = list(
#'     SubscriptionType = "SNS"|"EMAIL",
#'     Address = "string"
#'   )
#' )
#' ```
#'
#' @keywords internal
#'
#' @rdname budgets_update_subscriber
budgets_update_subscriber <- function(AccountId, BudgetName, Notification, OldSubscriber, NewSubscriber) {
  op <- new_operation(
    name = "UpdateSubscriber",
    http_method = "POST",
    http_path = "/",
    paginator = list()
  )
  input <- .budgets$update_subscriber_input(AccountId = AccountId, BudgetName = BudgetName, Notification = Notification, OldSubscriber = OldSubscriber, NewSubscriber = NewSubscriber)
  output <- .budgets$update_subscriber_output()
  config <- get_config()
  svc <- .budgets$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.budgets$operations$update_subscriber <- budgets_update_subscriber
